create or alter view vr_wv_ConfigurationValidation
as
-- Problem, EntityName, Severity, Impact, Actions
select 'A table listed in general lookup CCW_MULTI_UDTS does not exist in iMIS' 'Problem',
		gt.CODE 'Entity', 
		'2 - Medium' 'Severity',
		'wvSuite configuration page will allow invalid choices' 'Impact',
		'Remove the entry, or define the table' 'Suggestions'
	from dbo.Gen_Tables gt
	where gt.TABLE_NAME = 'CCW_MULTI_UDTS'
		and gt.CODE not in (select TABLE_NAME from dbo.UD_Table)
union
select 'A table listed in general lookup CCW_MULTI_UDTS is not a multi-instance table',
		gt.CODE,
		'2 - Medium',
		'wvSuite configuration page will allow invalid choices',
		'Remove the entry, or change the table definition'
	from dbo.Gen_Tables gt
	join dbo.UD_Table ut
		on gt.CODE = ut.TABLE_NAME
	where gt.TABLE_NAME = 'CCW_MULTI_UDTS'
		and ut.ALLOW_MULTIPLE_INSTANCES = 0
union
select 'A PagePart is defined in general lookup CCW_PAGEPART but no pages use this pagepart',
		gt.CODE,
		'3 - Low',
		'Configuration lookup longer than needed',
		'Remove the unneeded value, or use procedure pr_wv_UDTableToCCW to define a pagepart from a table, or define the PagePart manually.'
	from dbo.Gen_Tables gt
	where gt.TABLE_NAME = 'CCW_PAGEPART'
		and gt.CODE not in (select PAGEPART from dbo.Config_Custom_Web)
union
select distinct 'A PagePart defined in wvSuite configuration is not defined in general lookup CCW_PAGEPART',
		ccw.PAGEPART,
		'2 - Medium',
		'Configuration lookup will not allow using this value',
		'Add ''' + ccw.PAGEPART + ''' to the lookup'
	from dbo.Config_Custom_Web ccw
	where ccw.PAGEPART not in (select CODE from dbo.Gen_Tables where TABLE_NAME = 'CCW_PAGEPART')
union
select 'The primary table for the page is not defined, or not a multi-instance table',
		'Page code "' + CODE + '", table "' + SUBSTITUTE + '"',
		'1 - High',
		'wvSuite will crash for users',
		'Choose a different table, or define the table.'
	from dbo.Gen_Tables gt
	where gt.TABLE_NAME = 'CCW_'
union
select 'The configured field does not exist in the named table',
		'Pagepart ' + ccw.PAGEPART + ' field ' + ccw.DEMOG_TABLE_NAME + '.' + ccw.FIELD_NAME,
		'2 - Medium',
		'The field will be silently omitted from the page',
		'Add the physical field, or remove the configuration'
	from dbo.Config_Custom_Web ccw
	where ccw.FIELD_NAME not in ('ID', 'SEQN')
		and not exists (select 1 
			from dbo.UD_Field udf
			where udf.TABLE_NAME = ccw.DEMOG_TABLE_NAME
			and udf.FIELD_NAME = ccw.FIELD_NAME)
union
select 'The configured field is not capitalized the same as the physical field or has extra whitespace',
		'Pagepart ' + ccw.PAGEPART + ' correct spelling ' + udf.FIELD_NAME,
		'2 - Medium',
		'Parts of wvSuite will not see this field, causing errors',
		'Correct the configuration to match the exact capitalization'
	from dbo.Config_Custom_Web ccw
	join dbo.UD_Field udf
		on udf.TABLE_NAME = ccw.DEMOG_TABLE_NAME
		and udf.FIELD_NAME = ccw.FIELD_NAME
	where convert(varbinary(30), ccw.FIELD_NAME) != convert(varbinary(30), udf.FIELD_NAME)
union
select 'The lookup for a field does not exist in Gen_Tables or tr_RSMLibraryLookups',
		'Pagepart ' + ccw.PAGEPART + ' field ' + ccw.FIELD_NAME + ' lookup ' + ccw.VALIDATION_TABLE,
		'2 - Medium',
		'The field will be free-form instead of showing a lookup',
		'Add the lookup table, or remove the lookup, or fix the lookup, or omit the field'
	from dbo.Config_Custom_Web ccw
	where ccw.VALIDATION_TYPE = 'GENTABLE'
		and ccw.VALIDATION_TABLE not in (select LookupName from dbo.tr_RSMLibraryLookups)
union
select 'The lookup for a field is not capitalized the same as the physical field or has extra whitespace',
		'Pagepart ' + ccw.PAGEPART + ' field ' + ccw.FIELD_NAME + ' lookup "' + rll.LookupName + '"',
		'2 - Medium',
		'The field will be free-form instead of showing a lookup',
		'Add the lookup table, or remove the lookup, or fix the lookup, or omit the field'
	from dbo.Config_Custom_Web ccw
	join dbo.tr_RSMLibraryLookups rll
		on ccw.VALIDATION_TABLE = rll.LookupName
	where ccw.VALIDATION_TYPE = 'GENERAL'
		and convert(varbinary(30), ccw.VALIDATION_TABLE) != convert(varbinary(30), rll.LookupName)
go
-- Problem, EntityName, Severity, Impact, Actions


select * from Gen_Tables where TABLE_NAME = 'CCW_PAGEPRIMARYTABLE' and SUBSTITUTE not in (select TABLE_NAME from UD_Table where ALLOW_MULTIPLE_INSTANCES = 1)
select * from Gen_Tables where TABLE_NAME = 'CCW_PAGEPRIMARYTABLE' and not exists (select 1 from Config_Custom_Web where PAGEPART like CODE + '.%')
select * from Gen_Tables where TABLE_NAME = 'CCW_PAGEPRIMARYTABLE' and SUBSTITUTE not in (select TABLE_NAME from UD_Field where FIELD_NAME = 'SELECTOR_SINGLE')	-- Primary table must always be wvMI_Expanded

select * from UD_Field where TABLE_NAME = 'MCLE_DR_Generated_Data'

select * from Config_Custom_Web where PAGEPART like 'AOSCR.%'


select * from Gen_Tables where TABLE_NAME like 'CCW%' and TABLE_NAME > 'CCW_PAGEPART'

